pub fn match_scos(
pattern: &Pattern,
scos: &[StixObject],
) -> Result<MatchResult, MatchError>Expand description
Match a pattern against a flat list of cyber-observable objects, treated as a single observation.
pub fn match_scos(
pattern: &Pattern,
scos: &[StixObject],
) -> Result<MatchResult, MatchError>Match a pattern against a flat list of cyber-observable objects, treated as a single observation.